chrpa package
=============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   chrpa.main
   chrpa.tests

Module contents
---------------

.. automodule:: chrpa
   :members:
   :undoc-members:
   :show-inheritance:
